@@ -109,6 +109,8 @@ _service_endpoints_template = {
     'config': '{proto}://{host}:4641',
     'configservice': '{proto}://{host}:4641',
     'mwaa': '{proto}://{host}:4642',
+    'fis': '{proto}://{host}:4643',
+    'meteringmarketplace': '{proto}://{host}:4644',
 }
 
 # TODO remove service port mapping above entirely
